version_info = (0, 0, 17)
__title__ = "jt64env"
__version__ = '.'.join(str(c) for c in version_info)
__name__ = "jt64env"
__author__ = "Greg Beam, KI7MT"
__license__ = "GPLv3"
__email__ = "ki7mt@yahoo.com"
__summary__ = "JTSDK64 Tools Environment Variables"
